==> augmented-ui-1.1.2.tgz: package/README.md <==
![James0x57](https://img.shields.io/badge/James0x57%20%F0%9F%91%BD-I%20made%20a%20thing!-blueviolet.svg?labelColor=222222)

# augmented-ui from PropJockey

Home:
http://augmented-ui.com/

Docs:
http://augmented-ui.com/docs/

Informal/Visual Tests:
http://augmented-ui.com/test.html

NPM:
https://www.npmjs.com/package/augmented-ui

GitHub:
https://github.com/propjockey/augmented-ui

Install:
`$ npm install augmented-ui`
Then include the `/node_modules/augmented-ui/augmented.css` file before any stylesheets that use it.

OR

Use your favorite NPM CDN and include it on your page before other stylesheets for small projects. Like so:
```html
<link rel="stylesheet" type="text/css" href="https://unpkg.com/augmented-ui/augmented.css">
```

### data-augmented.css

You may, optionally, use data-augmented.css instead of augmented.css if you prefer to stick to standard markup. They are not interchangeable, please only use one or the other. The API is exactly the same, just instead of the `augmented-ui="tl-clip exe"` attributes, you'll use `data-augmented-ui="tl-clip exe"` instead. data-augmented.css is currently incompatible with aug-attr-spliced.js

## Support

### Sponsors

Become a sponsor and get your logo on this README with a link to your site. [[Become a sponsor](https://opencollective.com/augmented-ui)]

<a href="https://opencollective.com/augmented-ui/sponsor/0/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/0/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/1/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/1/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/2/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/2/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/3/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/3/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/4/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/4/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/5/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/5/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/6/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/6/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/7/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/7/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/8/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/8/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/9/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/9/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/10/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/10/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/11/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/11/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/12/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/12/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/13/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/13/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/14/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/14/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/15/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/15/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/16/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/16/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/17/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/17/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/18/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/18/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/19/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/19/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/20/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/20/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/21/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/21/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/22/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/22/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/23/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/23/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/24/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/24/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/25/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/25/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/26/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/26/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/27/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/27/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/28/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/28/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/29/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/29/avatar.svg"></a>

### Backers

Help the developer follow his excitement and support augmented-ui with a monthly donation. [[Become a backer](https://opencollective.com/augmented-ui)]

<a href="https://opencollective.com/augmented-ui/backer/0/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/0/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/1/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/1/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/2/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/2/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/3/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/3/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/4/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/4/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/5/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/5/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/6/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/6/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/7/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/7/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/8/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/8/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/9/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/9/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/10/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/10/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/11/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/11/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/12/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/12/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/13/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/13/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/14/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/14/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/15/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/15/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/16/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/16/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/17/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/17/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/18/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/18/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/19/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/19/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/20/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/20/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/21/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/21/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/22/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/22/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/23/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/23/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/24/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/24/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/25/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/25/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/26/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/26/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/27/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/27/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/28/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/28/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/29/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/29/avatar.svg"></a>

## CHANGELOG:

v1.1.2 - March 5th, 2020:
* Added data-augmented.css option for data- prefixed augmented-ui attribute.
* Added compatibility notes for specific frameworks/libraries at the bottom of this README

v1.1.0 - September 9th, 2019:
* Increased full support global user reach from ~70% to ~91% with -webkit-clip-path
* Bought an old iPhone to isolate and feature detect the iOS issue found before launch, enabling -webkit-clip-path to be used everywhere else
* Better docs: http://augmented-ui.com/docs/

v1.0.0 - August 31st, 2019:
* Initial release
* -webkit-clip-path support removed before release due to breaking issues on older iOS versions used by ~2% of global users

## Cross Compatibility

augmented-ui relies on dynamic and optional composition of standard comma-separated CSS properties. This requires a leading comma in a custom property + an empty fallback in var(). Here is a minimal example of how that works: https://jsbin.com/cemujarozo/1/edit?html,css,output

A common problem in CSS parsers is to erroneously give meaning to commas in custom properties, and then complain about having a leading comma. Even old versions of safari on iOS ran into this issue and they have since fixed it. Fortunately it can be safely feature detected to avoid problems in those versions of iOS: `@supports (--foo: , 0 0)`

### Compatibility with Create React App

Create React App depends on PostCSS and cssnano. Both of these libraries have parsing bugs that block augmented-ui so you'll need to copy augmented.css (or data-augmented.css) into the public folder and manually include it in the index.html file to avoid them until they're fixed.

You can read more about using the public folder here: https://create-react-app.dev/docs/using-the-public-folder/

You can read more about the Post CSS bug here (issue has been open for about 1 year): https://github.com/postcss/postcss-calc/issues/77

You can read more about the cssnano bug here (solved, but there hasn't been a release in over a year): https://github.com/cssnano/cssnano/issues/822

### Compatibility with styled-components in React

styled-components strips non-standard attributes so make sure to use `data-augmented.css`

### Compatibility in VSCode

VSCode complains about the leading comma and currently the only way to avoid it is to disable its CSS Validation.

You can read more about disabling it here: https://github.com/propjockey/augmented-ui/issues/2#issuecomment-540184111

You can read more about the issue here: https://github.com/microsoft/vscode/issues/82178

### Compatibility with SASS

SASS has multiple implementations/compilers, some have parsing bugs related to the leading comma in custom properties. The compiler used on sassmeister.com handles the leading comma correctly in custom properties (by ignoring it), but trips up when it's used in a supports statement `@supports (--foo: , 0 0)` If you run into trouble, include augmented.css separately from your SASS ecosystem.

### Other notes?

Please feel free to file an issue if you run into any trouble, I'll be glad to take a look and work on a path forward for you!

==> augmented-ui-2.0.0.tgz: package/README.md <==
![James0x57](https://img.shields.io/badge/James0x57%20%F0%9F%91%BD-I%20made%20a%20thing!-blueviolet.svg?labelColor=222222)

# augmented-ui from PropJockey

Resources:
* Home: http://augmented-ui.com/
* Docs: http://augmented-ui.com/docs/
* WYSIWYG Mixin Mixer: http://augmented-ui.com/mixinmixer/
* NPM: https://www.npmjs.com/package/augmented-ui
* GitHub: https://github.com/propjockey/augmented-ui
* Twitter: https://twitter.com/James0x57

Old v1 Links:
* Home: http://augmented-ui.com/v1/
* Docs: http://augmented-ui.com/v1/docs/
* Test: http://augmented-ui.com/v1/test.html
* unpkg: https://unpkg.com/augmented-ui@1/augmented.css

Install:
`$ npm install augmented-ui`
Then include the `/node_modules/augmented-ui/augmented-ui.min.css` file before any stylesheets that use it.

OR

Use your favorite NPM CDN and include it on your page before other stylesheets for small projects. Like so:
```html
<link rel="stylesheet" type="text/css" href="https://unpkg.com/augmented-ui@2/augmented-ui.min.css">
```

## Files

* **augmented-ui.css** - Everything, not minified (core, border and inlay mixins, individual-region mixins, all-region shape mixins)
* **augmented-ui.min.css** - Everything, minified (core, border and inlay mixins, individual-region mixins, all-region shape mixins)
* **aug-core.min.css** - core only, minified
* **border-inlay-mixins.min.css** - border and inlay mixins (and their delegate options) only, minified. Requires aug-core.min.css
* **region-mixins.min.css** - individual-region mixins only, minified. Requires aug-core.min.css
* **shape-mixins.min.css** - all-region mixins only, minified. Requires aug-core.min.css

## Support

http://augmented-ui.com/docs/#supporting-augmented-ui

### Sponsors

Become a sponsor and get your logo on this README with a link to your site. [[Become a sponsor](https://opencollective.com/augmented-ui)]

<a href="https://opencollective.com/augmented-ui/sponsor/0/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/0/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/1/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/1/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/2/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/2/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/3/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/3/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/4/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/4/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/5/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/5/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/6/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/6/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/7/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/7/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/8/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/8/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/9/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/9/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/10/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/10/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/11/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/11/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/12/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/12/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/13/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/13/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/14/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/14/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/15/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/15/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/16/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/16/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/17/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/17/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/18/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/18/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/19/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/19/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/20/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/20/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/21/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/21/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/22/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/22/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/23/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/23/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/24/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/24/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/25/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/25/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/26/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/26/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/27/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/27/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/28/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/28/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/sponsor/29/website" target="_blank"><img src="https://opencollective.com/augmented-ui/sponsor/29/avatar.svg"></a>

### Backers

Help the developer follow their excitement and support augmented-ui with a monthly donation. [[Become a backer](https://opencollective.com/augmented-ui)]

<a href="https://opencollective.com/augmented-ui/backer/0/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/0/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/1/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/1/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/2/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/2/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/3/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/3/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/4/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/4/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/5/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/5/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/6/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/6/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/7/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/7/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/8/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/8/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/9/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/9/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/10/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/10/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/11/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/11/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/12/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/12/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/13/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/13/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/14/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/14/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/15/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/15/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/16/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/16/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/17/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/17/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/18/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/18/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/19/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/19/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/20/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/20/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/21/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/21/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/22/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/22/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/23/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/23/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/24/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/24/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/25/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/25/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/26/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/26/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/27/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/27/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/28/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/28/avatar.svg"></a>
<a href="https://opencollective.com/augmented-ui/backer/29/website" target="_blank"><img src="https://opencollective.com/augmented-ui/backer/29/avatar.svg"></a>

## CHANGELOG:

v2.0.0 - August 30, 2020:
* Complete rewrite
* Over 200 aug mixins built on top of a new core feature set
* Mixin Mixer: http://augmented-ui.com/
* Properties that enable clip augs at any angle, not just 45deg
* Optionally equip augs dynamically from CSS using core, without DOM attribute mixins and without JavaScript (no more aug-attr-spliced.js!)
* Border size and Inlay (previously "Inset") distance gained individual top/right/bottom/left options
* Full support global user reach at 92.96%
* Automatic elliptical border-radius fallbacks removed to simplify adding augmented-ui to projects with legacy browser support

v1.1.2 - March 5th, 2020:
* Added data-augmented.css option for data- prefixed augmented-ui attribute.
* Added compatibility notes for specific frameworks/libraries at the bottom of this README

v1.1.0 - September 9th, 2019:
* Increased full support global user reach from ~70% to ~91% with -webkit-clip-path
* Bought an old iPhone to isolate and feature detect the iOS issue found before launch, enabling -webkit-clip-path to be used everywhere else
* Better docs: http://augmented-ui.com/docs/

v1.0.0 - August 31st, 2019:
* Initial release
* -webkit-clip-path support removed before release due to breaking issues on older iOS versions used by ~2% of global users
